@@ -5,12 +5,12 @@ from traceback import extract_tb
 
 
 if __package__:
-    from .process import main
+    from .launch import main
 else:
-    package_parent_path = dirname(dirname(__file__))
-    package_name = basename(dirname(__file__))
-    path.insert(0, package_parent_path)
-    main = import_module(f"{package_name}.process", package_name).main
+    package = dirname(__file__)
+    parent, target = dirname(package), basename(package)
+    path.insert(0, parent)
+    main = import_module(f"{target}.launch", target).main
 
 
 def process_exc_trace(exc_trace):
@@ -30,6 +30,11 @@ def write_error(exc_type, exc_value, exc_trace):
     stderr.write(f"{message}\n")
 
 
+def write_abort(exc_type, exc_value, exc_trace):
+    message = "ABORTED"
+    stderr.write(f"{message}\n")
+
+
 def write_interrupt(exc_type, exc_value, exc_trace):
     stack, location = process_exc_trace(exc_trace)
     message = " INTERRUPTED\n" \
@@ -44,6 +49,9 @@ if __name__ == "__main__":
     except KeyboardInterrupt:
         write_interrupt(*exc_info())
         raise SystemExit(1)
-    except Exception:
-        write_error(*exc_info())
+    except Exception as exc:
+        if str(exc).lower() == "aborted":
+            write_abort(*exc_info())
+        else:
+            write_error(*exc_info())
         raise SystemExit(1)
