@@ -5,7 +5,7 @@ CHR_SIZES_PATH="{ path file_exists }"
 
 
 # --- MODULES ---
-echo "# initializing environment and loading modules $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# INITIALIZING ENVIRONMENT AND LOADING MODULES $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 module reset
 export MUGQIC_INSTALL_HOME="/cvmfs/soft.mugqic/CentOS6"
 module use "$MUGQIC_INSTALL_HOME/modulefiles"
@@ -13,7 +13,7 @@ module load bedtools/2.30 mugqic/ucsc/v387
 
 
 # --- 1 BIGBED ---
-echo "# bigbed: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# BIGBED: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 bedtools bamtobed -i "$BASE_PATH.bam" > "$BASE_PATH.tmp.bed"
 bedSort "$BASE_PATH.tmp.bed" "$BASE_PATH.tmp.sorted.bed"
 rm "$BASE_PATH.tmp.bed"
@@ -22,4 +22,4 @@ rm "$BASE_PATH.tmp.sorted.bed"
 
 
 # --- DONE ---
-echo "# done $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# DONE $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
