@@ -6,7 +6,7 @@ BIGWIG_BIN_SIZE="{ integer > 0 }"
 
 
 # --- MODULES ---
-echo "# initializing environment and loading modules $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# INITIALIZING ENVIRONMENT AND LOADING MODULES $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 module reset
 export MUGQIC_INSTALL_HOME="/cvmfs/soft.mugqic/CentOS6"
 module use "$MUGQIC_INSTALL_HOME/modulefiles"
@@ -14,9 +14,9 @@ module load mugqic/deepTools/3.5.0
 
 
 # --- 1 BIGWIG ---
-echo "# bigwig: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# BIGWIG: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 bamCoverage -b "$BASE_PATH.bam" -o "$BASE_PATH.fpkm.bigwig" -bs "$BIGWIG_BIN_SIZE" -e 150 --normalizeUsing RPKM -p "$CPU_CORES"
 
 
 # --- DONE ---
-echo "# done $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# DONE $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
