@@ -8,7 +8,7 @@ BIGWIG_BIN_SIZE="{ integer > 0 }"
 
 
 # --- MODULES ---
-echo "# initializing environment and loading modules $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# INITIALIZING ENVIRONMENT AND LOADING MODULES $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 module reset
 module load python/3.9 java/13.0
 module load fastqc/0.11 bowtie2/2.4 bismark/0.22 samtools/1.12
@@ -32,7 +32,7 @@ function reads-diff {
     local INITIAL="$(reads-count "$1" "$2")"
     local FINAL="$(reads-count "$3" "$4")"
     local PERCENT="$(echo "scale=2 ; $FINAL / $INITIAL * 100" | bc)"
-    echo "reads: initial=$INITIAL final=$FINAL ($PERCENT%)"
+    echo "reads: initial=$INITIAL final=$FINAL ($PERCENT% of initial)"
 }
 
 
@@ -46,7 +46,7 @@ wait
 
 
 # --- 1 QC AND TRIMMING ---
-echo "# qc and trimming: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# QC AND TRIMMING: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 TRIM_READS_SCRIPT_PATH="$BASE_PATH.tmp.trim_reads.py"
 cat << EOM | tr -d "[:space:]" | base64 -d | gzip -dc > "$TRIM_READS_SCRIPT_PATH"
 H4sIANKKdWMCA6RX53LrthL+z6fY4W1kxtI1lV6U3nu5vXkgcUlhDAIMALqlPPvdBSAaoTVxzjk8xcRiy/dtAWg5jMZ6ELYfhXVYpHV/J8fj+0G4g5K741KZvpe6Py6HSXk5WrNH5zKxccc3Ozt1t7PQHyyKNtP3
@@ -109,7 +109,7 @@ mv "$BASE_PATH.trimmed.r2_fastqc.html" "$BASE_PATH.qc/$(basename "$BASE_PATH").t
 
 
 # --- 2 ALIGNEMENT ---
-echo "# alignment: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# ALIGNMENT: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 BP="$(echo "scale=0 ; $CPU_CORES / 4" | bc)" ; BP="$([ $BP -eq 0 ] && echo 1 || echo $BP)"
 BL="$BASE_PATH.tmp.bismark_log.txt"
 bismark --non_directional --gzip --parallel "$BP" --temp_dir "$(dirname "$BASE_PATH")" -o "$(dirname "$BASE_PATH")" "$BISMARK_GENOME_PATH" -1 "$BASE_PATH.trimmed.r1.fastq.gz" -2 "$BASE_PATH.trimmed.r2.fastq.gz" > "$BL" 2>&1
@@ -125,7 +125,7 @@ rm "$BASE_PATH.pre.bam"
 
 
 # --- 3 SORTING ---
-echo "# sorting: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# SORTING: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 mv "$BASE_PATH.bam" "$BASE_PATH.unsorted.bam"
 samtools sort -@ "$CPU_CORES" -o "$BASE_PATH.bam" "$BASE_PATH.unsorted.bam"
 samtools index -@ "$CPU_CORES" "$BASE_PATH.bam"
@@ -134,7 +134,7 @@ rm "$BASE_PATH.unsorted.bam"
 
 
 # --- 4 DUPLICATES ---
-echo "# duplicates: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# DUPLICATES: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 mv "$BASE_PATH.bam" "$BASE_PATH.with_duplicates.bam"
 mv "$BASE_PATH.bam.bai" "$BASE_PATH.with_duplicates.bam.bai"
 samtools markdup -@ "$CPU_CORES" -r -s "$BASE_PATH.with_duplicates.bam" "$BASE_PATH.bam"
@@ -144,7 +144,7 @@ echo "duplicates: $(reads-diff bam "$BASE_PATH.with_duplicates.bam" bam "$BASE_P
 
 
 # --- 5 BIGWIG ---
-echo "# bigwig: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# BIGWIG: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 bamCoverage -b "$BASE_PATH.bam" -o "$BASE_PATH.cpm.bigwig" -bs "$BIGWIG_BIN_SIZE" -e 150 --normalizeUsing BPM -p "$CPU_CORES"
 [ "$BAM_WITH_DUPLICATES" != remove ] && bamCoverage -b "$BASE_PATH.with_duplicates.bam" -o "$BASE_PATH.with_duplicates.cpm.bigwig" -bs "$BIGWIG_BIN_SIZE" -e 150 --normalizeUsing BPM -p "$CPU_CORES"
 
@@ -165,4 +165,4 @@ BASE_PATH="$ORIGINAL_BASE_PATH"
 
 
 # --- DONE ---
-echo "# done $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
\ No newline at end of file
+printf "\n\n%s\n" "# DONE $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
