@@ -8,7 +8,7 @@ BIGWIG_BIN_SIZE="{ integer > 0 }"
 
 
 # --- MODULES ---
-echo "# initializing environment and loading modules $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# INITIALIZING ENVIRONMENT AND LOADING MODULES $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 module reset
 export MUGQIC_INSTALL_HOME="/cvmfs/soft.mugqic/CentOS6"
 module use "$MUGQIC_INSTALL_HOME/modulefiles"
@@ -35,12 +35,12 @@ function reads-diff {
     local INITIAL="$(reads-count "$1" "$2")"
     local FINAL="$(reads-count "$3" "$4")"
     local PERCENT="$(echo "scale=2 ; $FINAL / $INITIAL * 100" | bc)"
-    echo "reads: initial=$INITIAL final=$FINAL ($PERCENT%)"
+    echo "reads: initial=$INITIAL final=$FINAL ($PERCENT% of initial)"
 }
 
 
 # --- 1 QC AND TRIMMING ---
-echo "# qc and trimming: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# QC AND TRIMMING: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 TRIM_READS_SCRIPT_PATH="$BASE_PATH.tmp.trim_reads.py"
 cat << EOM | tr -d "[:space:]" | base64 -d | gzip -dc > "$TRIM_READS_SCRIPT_PATH"
 H4sIANKKdWMCA6RX53LrthL+z6fY4W1kxtI1lV6U3nu5vXkgcUlhDAIMALqlPPvdBSAaoTVxzjk8xcRiy/dtAWg5jMZ6ELYfhXVYpHV/J8fj+0G4g5K741KZvpe6Py6HSXk5WrNH5zKxccc3Ozt1t7PQHyyKNtP3
@@ -103,13 +103,13 @@ mv "$BASE_PATH.trimmed.r2_fastqc.html" "$BASE_PATH.qc/$(basename "$BASE_PATH").t
 
 
 # --- 2 ALIGNEMENT ---
-echo "# alignment: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# ALIGNMENT: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 bowtie2 -p "$CPU_CORES" --fr --no-unal --no-mixed --no-discordant -x "$BOWTIE2_INDEX_PATH" -1 "$BASE_PATH.trimmed.r1.fastq.gz" -2 "$BASE_PATH.trimmed.r2.fastq.gz" |
 samtools fixmate -@ "$CPU_CORES" -m /dev/stdin "$BASE_PATH.bam"
 
 
 # --- 3 SORTING ---
-echo "# sorting: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# SORTING: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 mv "$BASE_PATH.bam" "$BASE_PATH.unsorted.bam"
 samtools sort -@ "$CPU_CORES" -o "$BASE_PATH.bam" "$BASE_PATH.unsorted.bam"
 samtools index -@ "$CPU_CORES" "$BASE_PATH.bam"
@@ -118,7 +118,7 @@ rm "$BASE_PATH.unsorted.bam"
 
 
 # --- 4 DUPLICATES ---
-echo "# duplicates: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# DUPLICATES: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 mv "$BASE_PATH.bam" "$BASE_PATH.with_duplicates.bam"
 mv "$BASE_PATH.bam.bai" "$BASE_PATH.with_duplicates.bam.bai"
 samtools markdup -@ "$CPU_CORES" -r -s "$BASE_PATH.with_duplicates.bam" "$BASE_PATH.bam"
@@ -128,9 +128,9 @@ echo "duplicates: $(reads-diff bam "$BASE_PATH.with_duplicates.bam" bam "$BASE_P
 
 
 # --- 5 BIGWIG ---
-echo "# bigwig: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# BIGWIG: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 bamCoverage -b "$BASE_PATH.bam" -o "$BASE_PATH.fpkm.bigwig" -bs "$BIGWIG_BIN_SIZE" -e 150 --normalizeUsing RPKM -p "$CPU_CORES"
 
 
 # --- DONE ---
-echo "# done $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
\ No newline at end of file
+printf "\n\n%s\n" "# DONE $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
