@@ -7,7 +7,7 @@ MACS2_GENOME_SIZE="{ regex mm|hs|cc|dm|[0-9]+ }"
 
 
 # --- MODULES ---
-echo "# initializing environment and loading modules $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# INITIALIZING ENVIRONMENT AND LOADING MODULES $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 module reset
 module load python/3.9
 virtualenv --no-download "$SLURM_TMPDIR/env.python.3"
@@ -18,7 +18,7 @@ chmod +x "$SLURM_TMPDIR/env.python.3/bin/"* 2> /dev/null
 
 
 # --- 1 PEAK CALLING ---
-echo "# peak calling: start $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
+printf "\n\n%s\n" "# PEAK CALLING: START $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
 MACS2_OUTPUT_PATH="$BASE_PATH.$MACS2_PVALUE.peaks"
 [ -d "$MACS2_OUTPUT_PATH" ] || mkdir "$MACS2_OUTPUT_PATH"
 if [ "$MACS2_CONTROL_PATH" = "" ]; then
@@ -49,4 +49,4 @@ rm "$REFORMAT_MACS2_SCRIPT_PATH"
 
 
 # --- DONE ---
-echo "# done $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
\ No newline at end of file
+printf "\n\n%s\n" "# DONE $(date '+%Y/%m/%d %H:%M:%S UTC%:::z')" >&2
